# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import project_project_stage_delete
from . import project_task_type_delete
from . import project_share_wizard
from . import project_share_collaborator_wizard
